import { createRouter, createWebHistory, RouteRecordRaw, createWebHashHistory } from 'vue-router';
import { useStore } from 'vuex';
import appSetting from '@/app-setting';
import HomeView from '../views/index.vue';

const constantRouterMap: RouteRecordRaw[] = [
    { path: '/login', component: () => import('@/views/auth/boxed-signin.vue'), meta: { layout: 'auth' } },
];

const router = createRouter({
    history: createWebHashHistory(),
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRouterMap
});

const asyncRouterMap: RouteRecordRaw[] = [
    {
        path: '/',
        redirect: '/dashboard',
        name: 'dashboard',
        children: [
            { path: 'dashboard', component: () => import('@/views/index.vue'), name: 'dashboard', meta: { title: 'home', icon: 'dashboard', layout: 'app' } }
        ]
    },
    {
        path: '/stock',
        redirect: '/stock',
        name: 'stock',
        children: [
            { path: 'warehouseList', component: () => import('@/views/stock/warehouseList.vue'), name: 'warehouseList', meta: { title: 'warehouseList', layout: 'app' }, hidden: true },
            { path: 'goodsLend', component: () => import('@/views/stock/goodsLend.vue'), name: 'goodsLend', meta: { title: 'goodsLend', layout: 'app' }, hidden: true },
            { path: 'goodsTransfer', component: () => import('@/views/stock/goodsTransfer.vue'), name: 'goodsTransfer', meta: { title: 'goodsTransfer', layout: 'app' }, hidden: true },
            { path: 'goodsExchange', component: () => import('@/views/stock/warehousing.vue'), name: 'goodsExchange', meta: { title: 'goodsExchange' }, hidden: true },
            { path: 'goodsOutBound', component: () => import('@/views/stock/outbound.vue'), name: 'goodsOutBound', meta: { title: 'goodsOutBound' }, hidden: true },
        ]
    },
    {
        path: '/package',
        redirect: '/package',
        name: 'package',
        children: [
            { path: 'packageList', component: () => import('@/views/package/packageList.vue'), name: 'packageList', meta: { title: 'packageList', layout: 'app' } },
            { path: 'packagePermissions', component: () => import('@/views/package/packagePermissions.vue'), name: 'packagePermissions', meta: { title: 'packagePermissions', layout: 'app' } },
            { path: 'packageAdd', component: () => import('@/views/package/packageAdd.vue'), name: 'packageAdd', meta: { title: 'packageAdd', layout: 'app' } },
        ]
    },
    {
        path: '/templateManage',
        redirect: '/templateManage',
        name: 'templateManage',
        children: [
            { path: 'smsTemplate', component: () => import('@/views/templateManage/smsTemplate.vue'), name: 'smsTemplate', meta: { title: 'smsTemplate', layout: 'app' } },
            { path: 'systemMessage', component: () => import('@/views/templateManage/systemMessage.vue'), name: 'systemMessage', meta: { title: 'systemMessage', layout: 'app' } },
            { path: 'emailtemplate', component: () => import('@/views/templateManage/emailtemplate.vue'), name: 'emailtemplate', meta: { title: 'emailtemplate', layout: 'app' } },
           { path: 'accountTemplate', component: () => import('@/views/templateManage/accountTemplate.vue'), name: 'accountTemplate', meta: { title: 'accountTemplate', layout: 'app' } },
            /*{ path: 'goodsOutBound', component: () => import('@/views/templateManage/outbound.vue'), name: 'goodsOutBound', meta: { title: 'goodsOutBound' } }, */
        ]
    },
    {
        path: '/setting',
        redirect: '/setting',
        name: 'setting',
        meta: {
            title: 'setting',
            icon: 'setting-manage'
        },
        children: [
            { path: 'company', component: () => import('@/views/setting/company.vue'), name: 'company', meta: { title: 'company', layout: 'app' } },
            { path: 'roleManage', component: () => import('@/views/setting/roleManage.vue'), name: 'roleManage', meta: { title: 'roleManage', layout: 'app' }, hidden: true },
            { path: 'roleManageAdd', component: () => import('@/views/setting/roleManageAdd.vue'), name: 'roleManageAdd', meta: { title: 'roleManageAdd', layout: 'app' }, hidden: true },
            { path: 'branch', component: () => import('@/views/setting/branch.vue'), name: 'branch', meta: { title: 'branch', layout: 'app' }, hidden: true },
        ]
    },
];

asyncRouterMap.forEach(route => {
    router.addRoute(route);
});

export { constantRouterMap, asyncRouterMap };
export default router;